@@ -17,9 +17,9 @@ Mock unit tests for the NetApp driver utility module
 """
 
 import platform
+from unittest import mock
 
 import ddt
-import mock
 from oslo_concurrency import processutils as putils
 from oslo_log import log
 
@@ -90,7 +90,7 @@ class NetAppDriverUtilsTestCase(test.TestCase):
                           api_trace_pattern=regex)
 
     @na_utils.trace
-    def _trace_test_method(*args, **kwargs):
+    def _trace_test_method(self, *args, **kwargs):
         return 'OK'
 
     def test_trace_no_tracing(self):
