@@ -907,6 +907,8 @@ class ShareDriverTestCase(test.TestCase):
             'share_group_snapshot_id': 'fake_share_group_snapshot_id',
             'share_instance_id': 'fake_share_instance_id_1',
             'provider_location': 'should_not_be_used_1',
+            'share_name': 'share_fake_share_instance_id_1',
+            'name': 'share-snapshot-6813e06b-a8f5-4784-b17d-f3e91afa370e',
             'share': {
                 'id': '420f978b-dbf6-4b3c-92fe-f5b17a0bb5e2',
                 'size': 3,
@@ -919,6 +921,8 @@ class ShareDriverTestCase(test.TestCase):
             'share_group_snapshot_id': 'fake_share_group_snapshot_id',
             'share_instance_id': 'fake_share_instance_id_2',
             'provider_location': 'should_not_be_used_2',
+            'share_name': 'share_fake_share_instance_id_2',
+            'name': 'share-snapshot-1e010dfe-545b-432d-ab95-4ef03cd82f89',
             'share': {
                 'id': '420f978b-dbf6-4b3c-92fe-f5b17a0bb5e2',
                 'size': '2',
@@ -957,6 +961,8 @@ class ShareDriverTestCase(test.TestCase):
                  'share_instance_id': member['share']['id'],
                  'id': member['id'],
                  'share': member['share'],
+                 'share_name': member['share_name'],
+                 'name': member['name'],
                  'size': member['share']['size'],
                  'share_size': member['share']['size'],
                  'share_proto': member['share']['share_proto'],
@@ -979,6 +985,8 @@ class ShareDriverTestCase(test.TestCase):
             'share_group_snapshot_id': 'fake_share_group_snapshot_id',
             'share_instance_id': 'fake_share_instance_id_1',
             'provider_location': 'should_not_be_used_1',
+            'share_name': 'share_fake_share_instance_id_1',
+            'name': 'share-snapshot-6813e06b-a8f5-4784-b17d-f3e91afa370e',
             'share': {
                 'id': '420f978b-dbf6-4b3c-92fe-f5b17a0bb5e2',
                 'size': 3,
@@ -991,6 +999,8 @@ class ShareDriverTestCase(test.TestCase):
             'share_group_snapshot_id': 'fake_share_group_snapshot_id',
             'share_instance_id': 'fake_share_instance_id_2',
             'provider_location': 'should_not_be_used_2',
+            'share_name': 'share_fake_share_instance_id_2',
+            'name': 'share-snapshot-1e010dfe-545b-432d-ab95-4ef03cd82f89',
             'share': {
                 'id': '420f978b-dbf6-4b3c-92fe-f5b17a0bb5e2',
                 'size': '2',
@@ -1030,6 +1040,8 @@ class ShareDriverTestCase(test.TestCase):
             'share_instance_id': fake_snap_member_1['share']['id'],
             'id': fake_snap_member_1['id'],
             'share': fake_snap_member_1['share'],
+            'share_name': fake_snap_member_1['share_name'],
+            'name': fake_snap_member_1['name'],
             'size': fake_snap_member_1['share']['size'],
             'share_size': fake_snap_member_1['share']['size'],
             'share_proto': fake_snap_member_1['share']['share_proto'],
@@ -1043,6 +1055,8 @@ class ShareDriverTestCase(test.TestCase):
                  'share_instance_id': member['share']['id'],
                  'id': member['id'],
                  'share': member['share'],
+                 'share_name': member['share_name'],
+                 'name': member['name'],
                  'size': member['share']['size'],
                  'share_size': member['share']['size'],
                  'share_proto': member['share']['share_proto'],
@@ -1118,6 +1132,8 @@ class ShareDriverTestCase(test.TestCase):
             'share_group_snapshot_id': 'fake_share_group_snapshot_id',
             'share_instance_id': 'fake_share_instance_id_1',
             'provider_location': 'fake_provider_location_2',
+            'share_name': 'share_fake_share_instance_id_1',
+            'name': 'share-snapshot-6813e06b-a8f5-4784-b17d-f3e91afa370e',
             'share': {
                 'id': '420f978b-dbf6-4b3c-92fe-f5b17a0bb5e2',
                 'size': 3,
@@ -1130,6 +1146,8 @@ class ShareDriverTestCase(test.TestCase):
             'share_group_snapshot_id': 'fake_share_group_snapshot_id',
             'share_instance_id': 'fake_share_instance_id_2',
             'provider_location': 'fake_provider_location_2',
+            'share_name': 'share_fake_provider_location_2',
+            'name': 'share-snapshot-1e010dfe-545b-432d-ab95-4ef03cd82f89',
             'share': {
                 'id': '420f978b-dbf6-4b3c-92fe-f5b17a0bb5e2',
                 'size': '2',
@@ -1168,6 +1186,8 @@ class ShareDriverTestCase(test.TestCase):
                  'share': member['share'],
                  'size': member['share']['size'],
                  'share_size': member['share']['size'],
+                 'share_name': member['share_name'],
+                 'name': member['name'],
                  'share_proto': member['share']['share_proto'],
                  'provider_location': member['provider_location']},
                 share_server=None)
